busbus :bus: :bus:
======

.. image:: https://travis-ci.org/spaceboats/busbus.svg?branch=master
  :alt: Build Status
  :target: https://travis-ci.org/spaceboats/busbus
.. image:: https://img.shields.io/coveralls/spaceboats/busbus.svg?style=flat
  :alt: Coverage Status
  :target: https://coveralls.io/r/spaceboats/busbus

busbus is a platform for working with public transit data. It allows you to
query both realtime and scheduled arrivals as well as other information about
transit agencies.

In addition to its Python interface, it provides an optional WSGI application
so you can use busbus's data in any application with HTTP and JSON libraries.

Documentation is currently very limited but we're working on that. A demo of
using busbus is available as an asciicast:

.. image:: https://asciinema.org/a/19564.png
  :target: https://asciinema.org/a/19564

----

busbus was originally developed as a senior CS capstone project at the `KU EECS
department`_.

.. _KU EECS department: http://eecs.ku.edu/
